Module: Google::Cloud::ServiceControl::V1::CheckError::Code
- Defined in:
- proto_docs/google/api/servicecontrol/v1/check_error.rb
Overview
Error codes for Check responses.
Constant Summary collapse
- ERROR_CODE_UNSPECIFIED =
This is never used in
CheckResponse. 0- NOT_FOUND =
The consumer's project id, network container, or resource container was not found. Same as [google.rpc.Code.NOT_FOUND][google.rpc.Code.NOT_FOUND].
5- PERMISSION_DENIED =
The consumer doesn't have access to the specified resource. Same as [google.rpc.Code.PERMISSION_DENIED][google.rpc.Code.PERMISSION_DENIED].
7- RESOURCE_EXHAUSTED =
Quota check failed. Same as [google.rpc.Code.RESOURCE_EXHAUSTED][google.rpc.Code.RESOURCE_EXHAUSTED].
8- SERVICE_NOT_ACTIVATED =
The consumer hasn't activated the service.
104- BILLING_DISABLED =
The consumer cannot access the service because billing is disabled.
107- PROJECT_DELETED =
The consumer's project has been marked as deleted (soft deletion).
108- PROJECT_INVALID =
The consumer's project number or id does not represent a valid project.
114- CONSUMER_INVALID =
The input consumer info does not represent a valid consumer folder or organization.
125- IP_ADDRESS_BLOCKED =
The IP address of the consumer is invalid for the specific consumer project.
109- REFERER_BLOCKED =
The referer address of the consumer request is invalid for the specific consumer project.
110- CLIENT_APP_BLOCKED =
The client application of the consumer request is invalid for the specific consumer project.
111- API_TARGET_BLOCKED =
The API targeted by this request is invalid for the specified consumer project.
122- API_KEY_INVALID =
The consumer's API key is invalid.
105- API_KEY_EXPIRED =
The consumer's API Key has expired.
112- API_KEY_NOT_FOUND =
The consumer's API Key was not found in config record.
113- INVALID_CREDENTIAL =
The credential in the request can not be verified.
123- NAMESPACE_LOOKUP_UNAVAILABLE =
The backend server for looking up project id/number is unavailable.
300- SERVICE_STATUS_UNAVAILABLE =
The backend server for checking service status is unavailable.
301- BILLING_STATUS_UNAVAILABLE =
The backend server for checking billing status is unavailable.
302- CLOUD_RESOURCE_MANAGER_BACKEND_UNAVAILABLE =
Cloud Resource Manager backend server is unavailable.
305